@@ -54,20 +54,19 @@ class QgsSettingsEntryBool;
 class QgsSettingsEntryString;
 class QgsSettingsEntryColor;
 class QgsMapLayerProxyModel;
+class QgsLineSymbol;
 
 class QgsAppElevationProfileLayerTreeView : public QgsElevationProfileLayerTreeView
 {
     Q_OBJECT
   public:
-
     explicit QgsAppElevationProfileLayerTreeView( QgsLayerTree *rootNode, QWidget *parent = nullptr );
 
   protected:
-
     void contextMenuEvent( QContextMenuEvent *event ) override;
 };
 
-class QgsElevationProfileLayersDialog: public QDialog, private Ui::QgsElevationProfileAddLayersDialogBase
+class QgsElevationProfileLayersDialog : public QDialog, private Ui::QgsElevationProfileAddLayersDialogBase
 {
     Q_OBJECT
 
@@ -75,28 +74,27 @@ class QgsElevationProfileLayersDialog: public QDialog, private Ui::QgsElevationP
     QgsElevationProfileLayersDialog( QWidget *parent = nullptr );
     void setVisibleLayers( const QList<QgsMapLayer *> &layers );
     void setHiddenLayers( const QList<QgsMapLayer *> &layers );
-    QList< QgsMapLayer * > selectedLayers() const;
+    QList<QgsMapLayer *> selectedLayers() const;
 
   private slots:
 
     void filterVisible( bool enabled );
 
   private:
-
     QgsMapLayerProxyModel *mModel = nullptr;
-    QList< QgsMapLayer * > mVisibleLayers;
+    QList<QgsMapLayer *> mVisibleLayers;
 };
 
 class QgsElevationProfileWidget : public QWidget
 {
     Q_OBJECT
   public:
-
     static const QgsSettingsEntryDouble *settingTolerance;
     static const QgsSettingsEntryBool *settingShowLayerTree;
     static const QgsSettingsEntryBool *settingLockAxis;
     static const QgsSettingsEntryString *settingLastExportDir;
     static const QgsSettingsEntryColor *settingBackgroundColor;
+    static const QgsSettingsEntryBool *settingShowSubsections;
 
     QgsElevationProfileWidget( const QString &name );
     ~QgsElevationProfileWidget();
@@ -137,6 +135,8 @@ class QgsElevationProfileWidget : public QWidget
     void axisScaleLockToggled( bool active );
     void renameProfileTriggered();
     void onProjectElevationPropertiesChanged();
+    void showSubsectionsTriggered();
+    void editSubsectionsSymbology();
 
   private:
     QgsElevationProfileCanvas *mCanvas = nullptr;
@@ -158,12 +158,14 @@ class QgsElevationProfileWidget : public QWidget
     QAction *mNudgeRightAction = nullptr;
     QAction *mRenameProfileAction = nullptr;
     QAction *mLockRatioAction = nullptr;
+    QAction *mShowSubsectionsAction = nullptr;
+    QAction *mSubsectionsSymbologyAction = nullptr;
     QMenu *mDistanceUnitMenu = nullptr;
 
     QgsDockableWidgetHelper *mDockableWidgetHelper = nullptr;
-    std::unique_ptr< QgsMapToolProfileCurve > mCaptureCurveMapTool;
-    std::unique_ptr< QgsMapToolProfileCurveFromFeature > mCaptureCurveFromFeatureMapTool;
-    std::unique_ptr< QgsElevationProfileToolMeasure > mMeasureTool;
+    std::unique_ptr<QgsMapToolProfileCurve> mCaptureCurveMapTool;
+    std::unique_ptr<QgsMapToolProfileCurveFromFeature> mCaptureCurveFromFeatureMapTool;
+    std::unique_ptr<QgsElevationProfileToolMeasure> mMeasureTool;
     QgsGeometry mProfileCurve;
 
     QObjectUniquePtr<QgsRubberBand> mMapPointRubberBand;
@@ -181,18 +183,19 @@ class QgsElevationProfileWidget : public QWidget
 
     QgsElevationProfileWidgetSettingsAction *mSettingsAction = nullptr;
 
-    std::unique_ptr< QgsLayerTree > mLayerTree;
+    std::unique_ptr<QgsLayerTree> mLayerTree;
     QgsLayerTreeRegistryBridge *mLayerTreeBridge = nullptr;
     QgsElevationProfileLayerTreeView *mLayerTreeView = nullptr;
+
+    std::unique_ptr<QgsLineSymbol> mSubsectionsSymbol;
 };
 
 
-class QgsElevationProfileWidgetSettingsAction: public QWidgetAction
+class QgsElevationProfileWidgetSettingsAction : public QWidgetAction
 {
     Q_OBJECT
 
   public:
-
     QgsElevationProfileWidgetSettingsAction( QWidget *parent = nullptr );
 
     QgsDoubleSpinBox *toleranceSpinBox() { return mToleranceWidget; }
