@@ -976,7 +976,7 @@ bool QgsCompositionConverter::readMapXml( QgsLayoutItemMap *layoutItem, const QD
     mapGrid->setFrameFillColor2( QgsSymbolLayerUtils::decodeColor( gridElem.attribute( QStringLiteral( "frameFillColor2" ), QStringLiteral( "0,0,0,255" ) ) ) );
     mapGrid->setBlendMode( QgsPainting::getCompositionMode( static_cast< Qgis::BlendMode >( itemElem.attribute( QStringLiteral( "gridBlendMode" ), QStringLiteral( "0" ) ).toUInt() ) ) );
     const QDomElement gridSymbolElem = gridElem.firstChildElement( QStringLiteral( "symbol" ) );
-    QgsLineSymbol *lineSymbol = nullptr;
+    std::unique_ptr< QgsLineSymbol > lineSymbol;
     if ( gridSymbolElem.isNull() )
     {
       //old project file, read penWidth /penColorRed, penColorGreen, penColorBlue
@@ -990,7 +990,7 @@ bool QgsCompositionConverter::readMapXml( QgsLayoutItemMap *layoutItem, const QD
     {
       lineSymbol = QgsSymbolLayerUtils::loadSymbol<QgsLineSymbol>( gridSymbolElem, context );
     }
-    mapGrid->setLineSymbol( lineSymbol );
+    mapGrid->setLineSymbol( lineSymbol.release() );
 
     //annotation
     const QDomNodeList annotationNodeList = gridElem.elementsByTagName( QStringLiteral( "Annotation" ) );
@@ -1629,9 +1629,9 @@ bool QgsCompositionConverter::readPolyXml( T *layoutItem, const QDomElement &ite
     QgsReadWriteContext context;
     if ( project )
       context.setPathResolver( project->pathResolver( ) );
-    T2 *styleSymbol = QgsSymbolLayerUtils::loadSymbol<T2>( symbolElement, context );
+    std::unique_ptr< T2 > styleSymbol = QgsSymbolLayerUtils::loadSymbol<T2>( symbolElement, context );
     if ( styleSymbol )
-      layoutItem->setSymbol( styleSymbol );
+      layoutItem->setSymbol( styleSymbol.release() );
   }
   // Disable frame for shapes
   layoutItem->setFrameEnabled( false );
