@@ -326,7 +326,7 @@ bool QgsRasterAttributeTable::insertField( int position, const Field &field, QSt
   {
     mType = Qgis::RasterAttributeTableType::Thematic;
   }
-  else if ( field.usage == Qgis::RasterAttributeTableFieldUsage::Max || field.usage == Qgis::RasterAttributeTableFieldUsage::Max )
+  else if ( field.usage == Qgis::RasterAttributeTableFieldUsage::Min || field.usage == Qgis::RasterAttributeTableFieldUsage::Max )
   {
     mType = Qgis::RasterAttributeTableType::Athematic;
   }
@@ -1527,7 +1527,7 @@ QgsRasterRenderer *QgsRasterAttributeTable::createRenderer( QgsRasterDataProvide
   }
   else
   {
-    std::unique_ptr<QgsSingleBandPseudoColorRenderer> pseudoColorRenderer = std::make_unique<QgsSingleBandPseudoColorRenderer>( provider, bandNumber );
+    auto pseudoColorRenderer = std::make_unique<QgsSingleBandPseudoColorRenderer>( provider, bandNumber );
     QStringList labels;
     // Athematic classification is not supported, but the classificationColumn will be used for labels.
     // if it's not specified, try to guess it here.
@@ -1580,7 +1580,7 @@ QgsRasterRenderer *QgsRasterAttributeTable::createRenderer( QgsRasterDataProvide
         }
       }
     }
-    renderer.reset( pseudoColorRenderer.release() );
+    renderer = std::move( pseudoColorRenderer );
   }
 
   return renderer.release();
