@@ -14,6 +14,7 @@
  ***************************************************************************/
 
 #include "qgslayoutitemwidget.h"
+#include "moc_qgslayoutitemwidget.cpp"
 #include "qgspropertyoverridebutton.h"
 #include "qgslayout.h"
 #include "qgsproject.h"
@@ -40,8 +41,7 @@ QgsLayoutConfigObject::QgsLayoutConfigObject( QWidget *parent, QgsLayoutObject *
 {
   if ( mLayoutObject->layout() )
   {
-    connect( &mLayoutObject->layout()->reportContext(), &QgsLayoutReportContext::layerChanged,
-             this, [ = ] { updateDataDefinedButtons(); } );
+    connect( &mLayoutObject->layout()->reportContext(), &QgsLayoutReportContext::layerChanged, this, [=] { updateDataDefinedButtons(); } );
   }
   if ( layoutAtlas() )
   {
@@ -60,7 +60,7 @@ void QgsLayoutConfigObject::updateDataDefinedProperty()
   QgsLayoutObject::DataDefinedProperty key = QgsLayoutObject::DataDefinedProperty::NoProperty;
 
   if ( ddButton->propertyKey() >= 0 )
-    key = static_cast< QgsLayoutObject::DataDefinedProperty >( ddButton->propertyKey() );
+    key = static_cast<QgsLayoutObject::DataDefinedProperty>( ddButton->propertyKey() );
 
   if ( key == QgsLayoutObject::DataDefinedProperty::NoProperty )
   {
@@ -72,7 +72,7 @@ void QgsLayoutConfigObject::updateDataDefinedProperty()
   //set the data defined property and refresh the item
   if ( propertyAssociatesWithMultiFrame )
   {
-    if ( QgsLayoutFrame *frame = dynamic_cast< QgsLayoutFrame * >( mLayoutObject.data() ) )
+    if ( QgsLayoutFrame *frame = dynamic_cast<QgsLayoutFrame *>( mLayoutObject.data() ) )
     {
       if ( QgsLayoutMultiFrame *multiFrame = frame->multiFrame() )
       {
@@ -80,7 +80,7 @@ void QgsLayoutConfigObject::updateDataDefinedProperty()
         multiFrame->refresh();
       }
     }
-    else if ( QgsLayoutMultiFrame *multiFrame = dynamic_cast< QgsLayoutMultiFrame * >( mLayoutObject.data() ) )
+    else if ( QgsLayoutMultiFrame *multiFrame = dynamic_cast<QgsLayoutMultiFrame *>( mLayoutObject.data() ) )
     {
       multiFrame->dataDefinedProperties().setProperty( key, ddButton->toProperty() );
       multiFrame->refresh();
@@ -95,7 +95,7 @@ void QgsLayoutConfigObject::updateDataDefinedProperty()
 
 void QgsLayoutConfigObject::updateDataDefinedButtons()
 {
-  const QList< QgsPropertyOverrideButton * > buttons = findChildren< QgsPropertyOverrideButton * >();
+  const QList<QgsPropertyOverrideButton *> buttons = findChildren<QgsPropertyOverrideButton *>();
   for ( QgsPropertyOverrideButton *button : buttons )
   {
     button->setVectorLayer( coverageLayer() );
@@ -105,7 +105,7 @@ void QgsLayoutConfigObject::updateDataDefinedButtons()
 void QgsLayoutConfigObject::initializeDataDefinedButton( QgsPropertyOverrideButton *button, QgsLayoutObject::DataDefinedProperty key )
 {
   button->blockSignals( true );
-  button->init( static_cast< int >( key ), mLayoutObject->dataDefinedProperties(), QgsLayoutObject::propertyDefinitions(), coverageLayer() );
+  button->init( static_cast<int>( key ), mLayoutObject->dataDefinedProperties(), QgsLayoutObject::propertyDefinitions(), coverageLayer() );
   connect( button, &QgsPropertyOverrideButton::changed, this, &QgsLayoutConfigObject::updateDataDefinedProperty, Qt::UniqueConnection );
   button->registerExpressionContextGenerator( mLayoutObject );
   button->blockSignals( false );
@@ -119,20 +119,20 @@ void QgsLayoutConfigObject::updateDataDefinedButton( QgsPropertyOverrideButton *
   if ( button->propertyKey() < 0 || !mLayoutObject )
     return;
 
-  const QgsLayoutObject::DataDefinedProperty key = static_cast< QgsLayoutObject::DataDefinedProperty >( button->propertyKey() );
+  const QgsLayoutObject::DataDefinedProperty key = static_cast<QgsLayoutObject::DataDefinedProperty>( button->propertyKey() );
   const bool propertyAssociatesWithMultiFrame = QgsLayoutObject::propertyAssociatesWithParentMultiframe( key );
 
   //set the data defined property
   if ( propertyAssociatesWithMultiFrame )
   {
-    if ( QgsLayoutFrame *frame = dynamic_cast< QgsLayoutFrame * >( mLayoutObject.data() ) )
+    if ( QgsLayoutFrame *frame = dynamic_cast<QgsLayoutFrame *>( mLayoutObject.data() ) )
     {
       if ( QgsLayoutMultiFrame *multiFrame = frame->multiFrame() )
       {
         whileBlocking( button )->setToProperty( multiFrame->dataDefinedProperties().property( key ) );
       }
     }
-    else if ( QgsLayoutMultiFrame *multiFrame = dynamic_cast< QgsLayoutMultiFrame * >( mLayoutObject.data() ) )
+    else if ( QgsLayoutMultiFrame *multiFrame = dynamic_cast<QgsLayoutMultiFrame *>( mLayoutObject.data() ) )
     {
       whileBlocking( button )->setToProperty( multiFrame->dataDefinedProperties().property( key ) );
     }
@@ -154,7 +154,7 @@ QgsLayoutAtlas *QgsLayoutConfigObject::layoutAtlas() const
     return nullptr;
   }
 
-  QgsPrintLayout *printLayout = qobject_cast< QgsPrintLayout * >( mLayoutObject->layout() );
+  QgsPrintLayout *printLayout = qobject_cast<QgsPrintLayout *>( mLayoutObject->layout() );
 
   if ( !printLayout )
   {
@@ -191,7 +191,6 @@ QgsLayoutItemBaseWidget::QgsLayoutItemBaseWidget( QWidget *parent, QgsLayoutObje
   , mConfigObject( new QgsLayoutConfigObject( this, layoutObject ) )
   , mObject( layoutObject )
 {
-
 }
 
 QgsLayoutObject *QgsLayoutItemBaseWidget::layoutObject()
@@ -241,7 +240,6 @@ void QgsLayoutItemBaseWidget::setDesignerInterface( QgsLayoutDesignerInterface *
 
 void QgsLayoutItemBaseWidget::setMasterLayout( QgsMasterLayoutInterface * )
 {
-
 }
 
 void QgsLayoutItemBaseWidget::registerDataDefinedButton( QgsPropertyOverrideButton *button, QgsLayoutObject::DataDefinedProperty property )
@@ -330,19 +328,19 @@ QgsLayoutItemPropertiesWidget::QgsLayoutItemPropertiesWidget( QWidget *parent, Q
 
   connect( mFrameColorButton, &QgsColorButton::colorChanged, this, &QgsLayoutItemPropertiesWidget::mFrameColorButton_colorChanged );
   connect( mBackgroundColorButton, &QgsColorButton::colorChanged, this, &QgsLayoutItemPropertiesWidget::mBackgroundColorButton_colorChanged );
-  connect( mStrokeWidthSpinBox, static_cast < void ( QDoubleSpinBox::* )( double ) > ( &QDoubleSpinBox::valueChanged ), this, &QgsLayoutItemPropertiesWidget::mStrokeWidthSpinBox_valueChanged );
+  connect( mStrokeWidthSpinBox, static_cast<void ( QDoubleSpinBox::* )( double )>( &QDoubleSpinBox::valueChanged ), this, &QgsLayoutItemPropertiesWidget::mStrokeWidthSpinBox_valueChanged );
   connect( mStrokeUnitsComboBox, &QgsLayoutUnitsComboBox::unitChanged, this, &QgsLayoutItemPropertiesWidget::strokeUnitChanged );
   connect( mFrameGroupBox, &QgsCollapsibleGroupBoxBasic::toggled, this, &QgsLayoutItemPropertiesWidget::mFrameGroupBox_toggled );
   connect( mFrameJoinStyleCombo, static_cast<void ( QComboBox::* )( int )>( &QComboBox::currentIndexChanged ), this, &QgsLayoutItemPropertiesWidget::mFrameJoinStyleCombo_currentIndexChanged );
   connect( mBackgroundGroupBox, &QgsCollapsibleGroupBoxBasic::toggled, this, &QgsLayoutItemPropertiesWidget::mBackgroundGroupBox_toggled );
   connect( mItemIdLineEdit, &QLineEdit::editingFinished, this, &QgsLayoutItemPropertiesWidget::mItemIdLineEdit_editingFinished );
   connect( mExportGroupNameCombo, &QComboBox::currentTextChanged, this, &QgsLayoutItemPropertiesWidget::exportGroupNameEditingFinished );
-  connect( mPageSpinBox, static_cast < void ( QSpinBox::* )( int ) > ( &QSpinBox::valueChanged ), this, &QgsLayoutItemPropertiesWidget::mPageSpinBox_valueChanged );
-  connect( mXPosSpin, static_cast < void ( QDoubleSpinBox::* )( double ) > ( &QDoubleSpinBox::valueChanged ), this, &QgsLayoutItemPropertiesWidget::mXPosSpin_valueChanged );
-  connect( mYPosSpin, static_cast < void ( QDoubleSpinBox::* )( double ) > ( &QDoubleSpinBox::valueChanged ), this, &QgsLayoutItemPropertiesWidget::mYPosSpin_valueChanged );
+  connect( mPageSpinBox, static_cast<void ( QSpinBox::* )( int )>( &QSpinBox::valueChanged ), this, &QgsLayoutItemPropertiesWidget::mPageSpinBox_valueChanged );
+  connect( mXPosSpin, static_cast<void ( QDoubleSpinBox::* )( double )>( &QDoubleSpinBox::valueChanged ), this, &QgsLayoutItemPropertiesWidget::mXPosSpin_valueChanged );
+  connect( mYPosSpin, static_cast<void ( QDoubleSpinBox::* )( double )>( &QDoubleSpinBox::valueChanged ), this, &QgsLayoutItemPropertiesWidget::mYPosSpin_valueChanged );
   connect( mPosUnitsComboBox, &QgsLayoutUnitsComboBox::unitChanged, this, &QgsLayoutItemPropertiesWidget::positionUnitsChanged );
-  connect( mWidthSpin, static_cast < void ( QDoubleSpinBox::* )( double ) > ( &QDoubleSpinBox::valueChanged ), this, &QgsLayoutItemPropertiesWidget::mWidthSpin_valueChanged );
-  connect( mHeightSpin, static_cast < void ( QDoubleSpinBox::* )( double ) > ( &QDoubleSpinBox::valueChanged ), this, &QgsLayoutItemPropertiesWidget::mHeightSpin_valueChanged );
+  connect( mWidthSpin, static_cast<void ( QDoubleSpinBox::* )( double )>( &QDoubleSpinBox::valueChanged ), this, &QgsLayoutItemPropertiesWidget::mWidthSpin_valueChanged );
+  connect( mHeightSpin, static_cast<void ( QDoubleSpinBox::* )( double )>( &QDoubleSpinBox::valueChanged ), this, &QgsLayoutItemPropertiesWidget::mHeightSpin_valueChanged );
   connect( mSizeUnitsComboBox, &QgsLayoutUnitsComboBox::unitChanged, this, &QgsLayoutItemPropertiesWidget::sizeUnitsChanged );
   connect( mUpperLeftRadioButton, &QRadioButton::toggled, this, &QgsLayoutItemPropertiesWidget::mUpperLeftCheckBox_stateChanged );
   connect( mUpperMiddleRadioButton, &QRadioButton::toggled, this, &QgsLayoutItemPropertiesWidget::mUpperMiddleCheckBox_stateChanged );
@@ -354,7 +352,7 @@ QgsLayoutItemPropertiesWidget::QgsLayoutItemPropertiesWidget( QWidget *parent, Q
   connect( mLowerMiddleRadioButton, &QRadioButton::toggled, this, &QgsLayoutItemPropertiesWidget::mLowerMiddleCheckBox_stateChanged );
   connect( mLowerRightRadioButton, &QRadioButton::toggled, this, &QgsLayoutItemPropertiesWidget::mLowerRightCheckBox_stateChanged );
   connect( mBlendModeCombo, static_cast<void ( QComboBox::* )( int )>( &QComboBox::currentIndexChanged ), this, &QgsLayoutItemPropertiesWidget::mBlendModeCombo_currentIndexChanged );
-  connect( mItemRotationSpinBox, static_cast < void ( QDoubleSpinBox::* )( double ) > ( &QDoubleSpinBox::valueChanged ), this, &QgsLayoutItemPropertiesWidget::mItemRotationSpinBox_valueChanged );
+  connect( mItemRotationSpinBox, static_cast<void ( QDoubleSpinBox::* )( double )>( &QDoubleSpinBox::valueChanged ), this, &QgsLayoutItemPropertiesWidget::mItemRotationSpinBox_valueChanged );
   connect( mExcludeFromPrintsCheckBox, &QCheckBox::toggled, this, &QgsLayoutItemPropertiesWidget::mExcludeFromPrintsCheckBox_toggled );
 
   //make button exclusive
@@ -377,8 +375,7 @@ QgsLayoutItemPropertiesWidget::QgsLayoutItemPropertiesWidget( QWidget *parent, Q
   connect( mOpacityWidget, &QgsOpacityWidget::opacityChanged, this, &QgsLayoutItemPropertiesWidget::opacityChanged );
 
   updateVariables();
-  connect( mVariableEditor, &QgsVariableEditorWidget::scopeChanged, this, [ = ]
-  {
+  connect( mVariableEditor, &QgsVariableEditorWidget::scopeChanged, this, [=] {
     if ( !mBlockVariableUpdates )
       QgsLayoutItemPropertiesWidget::variablesChanged();
   } );
@@ -426,7 +423,7 @@ void QgsLayoutItemPropertiesWidget::setItem( QgsLayoutItem *item )
 
 void QgsLayoutItemPropertiesWidget::setMasterLayout( QgsMasterLayoutInterface *masterLayout )
 {
-  if ( QgsPrintLayout *printLayout = dynamic_cast< QgsPrintLayout * >( masterLayout ) )
+  if ( QgsPrintLayout *printLayout = dynamic_cast<QgsPrintLayout *>( masterLayout ) )
   {
     connect( printLayout, &QgsPrintLayout::nameChanged, this, &QgsLayoutItemPropertiesWidget::updateVariables );
     connect( printLayout->atlas(), &QgsLayoutAtlas::coverageLayerChanged, this, &QgsLayoutItemPropertiesWidget::updateVariables );
@@ -500,7 +497,7 @@ void QgsLayoutItemPropertiesWidget::variablesChanged()
   if ( !mItem )
     return;
 
-  if ( QgsLayoutFrame *frame = qobject_cast< QgsLayoutFrame * >( mItem ) )
+  if ( QgsLayoutFrame *frame = qobject_cast<QgsLayoutFrame *>( mItem ) )
   {
     if ( QgsLayoutMultiFrame *mf = frame->multiFrame() )
     {
@@ -625,8 +622,7 @@ void QgsLayoutItemPropertiesWidget::setValuesForGuiPositionElements()
     return;
   }
 
-  auto block = [ = ]( bool blocked )
-  {
+  auto block = [=]( bool blocked ) {
     mXPosSpin->blockSignals( blocked );
     mYPosSpin->blockSignals( blocked );
     mPosUnitsComboBox->blockSignals( blocked );
@@ -766,7 +762,7 @@ void QgsLayoutItemPropertiesWidget::initializeDataDefinedButtons()
 
 void QgsLayoutItemPropertiesWidget::populateDataDefinedButtons()
 {
-  const QList< QgsPropertyOverrideButton * > buttons = findChildren< QgsPropertyOverrideButton * >();
+  const QList<QgsPropertyOverrideButton *> buttons = findChildren<QgsPropertyOverrideButton *>();
   for ( QgsPropertyOverrideButton *button : buttons )
   {
     mConfigObject->updateDataDefinedButton( button );
@@ -790,7 +786,7 @@ void QgsLayoutItemPropertiesWidget::setValuesForGuiElements()
   if ( QgsLayout *layout = mItem->layout() )
   {
     // collect export groups from layout, so that we can offer auto completion in the PDF export group combo
-    QList< QgsLayoutItem * > items;
+    QList<QgsLayoutItem *> items;
     layout->layoutItems( items );
     QStringList existingGroups;
     for ( const QgsLayoutItem *item : std::as_const( items ) )
@@ -800,8 +796,7 @@ void QgsLayoutItemPropertiesWidget::setValuesForGuiElements()
         existingGroups.append( groupName );
     }
 
-    std::sort( existingGroups.begin(), existingGroups.end(), [ = ]( const QString & a, const QString & b ) -> bool
-    {
+    std::sort( existingGroups.begin(), existingGroups.end(), [=]( const QString &a, const QString &b ) -> bool {
       return a.localeAwareCompare( b ) < 0;
     } );
 
