@@ -27,6 +27,8 @@
 #include "qgsmapcanvastracer.h"
 #include "testqgsmaptoolutils.h"
 
+#include <QSignalSpy>
+
 
 /**
  * \ingroup UnitTests
@@ -42,14 +44,18 @@ class TestQgsMapToolReshape : public QObject
     void initTestCase();    // will be called before the first testfunction is executed.
     void cleanupTestCase(); // will be called after the last testfunction was executed.
 
+    void testReshapeNotEnoughPoints();
     void testReshapeNoChange();
     void testReshapeZ();
     void testTopologicalEditing();
     void testTopologicalEditingNoSnap();
     void testAvoidIntersectionAndTopoEdit();
+    void testAvoidIntersectionAndTopoEditSameLayer();
+    void testAvoidIntersectionAndTopoEditSameLayerSelection();
     void reshapeWithBindingLine();
     void testWithTracing();
     void testKeepDirection();
+    void testWithSnapToSegment();
 
   private:
     QgisApp *mQgisApp = nullptr;
@@ -220,6 +226,27 @@ void TestQgsMapToolReshape::cleanupTestCase()
   QgsApplication::exitQgis();
 }
 
+void TestQgsMapToolReshape::testReshapeNotEnoughPoints()
+{
+  TestQgsMapToolAdvancedDigitizingUtils utils( mCaptureTool );
+  // no snapping for this test
+  QgsSnappingConfig cfg = mCanvas->snappingUtils()->config();
+  cfg.setEnabled( false );
+  mCanvas->snappingUtils()->setConfig( cfg );
+
+  const QSignalSpy editCommandSpy( mLayerLineZ, &QgsVectorLayer::editCommandStarted );
+
+  utils.mouseClick( 2, 2, Qt::LeftButton );
+  utils.mouseClick( 3, 2, Qt::RightButton );
+
+  // activate back snapping
+  cfg.setEnabled( true );
+  mCanvas->snappingUtils()->setConfig( cfg );
+
+  QCOMPARE( editCommandSpy.count(), 0 );
+  QCOMPARE( mLayerLineZ->undoStack()->index(), 0 );
+}
+
 void TestQgsMapToolReshape::testReshapeNoChange()
 {
   TestQgsMapToolAdvancedDigitizingUtils utils( mCaptureTool );
@@ -385,6 +412,97 @@ void TestQgsMapToolReshape::testAvoidIntersectionAndTopoEdit()
   mCaptureTool->setAutoSnapEnabled( isAutoSnapEnabled );
 }
 
+void TestQgsMapToolReshape::testAvoidIntersectionAndTopoEditSameLayer()
+{
+  QList<QgsMapLayer *> layers = { mLayerTopo, mLayerTopo2 };
+  QgsProject::instance()->addMapLayers( layers );
+  mCanvas->setLayers( layers );
+
+  // backup project settings
+  const bool topologicalEditing = QgsProject::instance()->topologicalEditing();
+  const Qgis::AvoidIntersectionsMode mode( QgsProject::instance()->avoidIntersectionsMode() );
+  const QList<QgsVectorLayer *> vlayers = QgsProject::instance()->avoidIntersectionsLayers();
+  const bool isAutoSnapEnabled = mCaptureTool->isAutoSnapEnabled();
+
+  QgsProject::instance()->setAvoidIntersectionsMode( Qgis::AvoidIntersectionsMode::AvoidIntersectionsLayers );
+  QgsProject::instance()->setAvoidIntersectionsLayers( { mLayerTopo, mLayerTopo2 } );
+  QgsProject::instance()->setTopologicalEditing( true );
+  mCanvas->setCurrentLayer( mLayerTopo );
+  mCaptureTool->setAutoSnapEnabled( false );
+  TestQgsMapToolAdvancedDigitizingUtils utils( mCaptureTool );
+
+  // reshape mLayerTopo feature 1 with two points inside mLayerTopo feature 2, both features should be reshaped
+  utils.mouseClick( 4, 4, Qt::LeftButton, Qt::KeyboardModifiers() );
+  utils.mouseClick( 7, 4, Qt::LeftButton, Qt::KeyboardModifiers() );
+  utils.mouseClick( 7.5, 3, Qt::LeftButton, Qt::KeyboardModifiers() );
+  utils.mouseClick( 7.5, 1, Qt::LeftButton, Qt::KeyboardModifiers() );
+  utils.mouseClick( 7, 0, Qt::LeftButton, Qt::KeyboardModifiers() );
+  utils.mouseClick( 4, 0, Qt::LeftButton, Qt::KeyboardModifiers() );
+  utils.mouseClick( 4, 0, Qt::RightButton );
+
+  QCOMPARE( mLayerTopo2->getFeature( 1 ).geometry().asWkt(), QStringLiteral( "Polygon ((0 5, 4 5, 4 7, 0 7, 0 5))" ) );
+  QCOMPARE( mLayerTopo->getFeature( 1 ).geometry().asWkt(), QStringLiteral( "Polygon ((4 0, 7 0, 7.5 1, 7.5 3, 7 4, 4 4, 0 4, 0 0, 4 0))" ) );
+  QCOMPARE( mLayerTopo->getFeature( 2 ).geometry().asWkt(), QStringLiteral( "Polygon ((7 0, 8 0, 8 4, 7 4, 7.5 3, 7.5 1, 7 0))" ) );
+
+  mLayerTopo->undoStack()->undo();
+
+  QCOMPARE( mLayerTopo2->getFeature( 1 ).geometry().asWkt(), QStringLiteral( "Polygon ((0 5, 4 5, 4 7, 0 7, 0 5))" ) );
+  QCOMPARE( mLayerTopo->getFeature( 1 ).geometry().asWkt(), QStringLiteral( "Polygon ((0 0, 4 0, 4 4, 0 4, 0 0))" ) );
+  QCOMPARE( mLayerTopo->getFeature( 2 ).geometry().asWkt(), QStringLiteral( "Polygon ((7 0, 8 0, 8 4, 7 4, 7 0))" ) );
+
+  QgsProject::instance()->setTopologicalEditing( topologicalEditing );
+  QgsProject::instance()->setAvoidIntersectionsMode( mode );
+  QgsProject::instance()->setAvoidIntersectionsLayers( vlayers );
+  mCaptureTool->setAutoSnapEnabled( isAutoSnapEnabled );
+}
+
+void TestQgsMapToolReshape::testAvoidIntersectionAndTopoEditSameLayerSelection()
+{
+  QList<QgsMapLayer *> layers = { mLayerTopo, mLayerTopo2 };
+  QgsProject::instance()->addMapLayers( layers );
+  mCanvas->setLayers( layers );
+
+  // backup project settings
+  const bool topologicalEditing = QgsProject::instance()->topologicalEditing();
+  const Qgis::AvoidIntersectionsMode mode( QgsProject::instance()->avoidIntersectionsMode() );
+  const QList<QgsVectorLayer *> vlayers = QgsProject::instance()->avoidIntersectionsLayers();
+  const bool isAutoSnapEnabled = mCaptureTool->isAutoSnapEnabled();
+
+  QgsProject::instance()->setAvoidIntersectionsMode( Qgis::AvoidIntersectionsMode::AvoidIntersectionsLayers );
+  QgsProject::instance()->setAvoidIntersectionsLayers( { mLayerTopo, mLayerTopo2 } );
+  QgsProject::instance()->setTopologicalEditing( true );
+  mCanvas->setCurrentLayer( mLayerTopo );
+  mCaptureTool->setAutoSnapEnabled( false );
+  TestQgsMapToolAdvancedDigitizingUtils utils( mCaptureTool );
+
+  mLayerTopo->selectByIds( { 1 } );
+
+  // reshape mLayerTopo feature 1 with two points inside mLayerTopo feature 2, only the selected feature should be reshaped
+  utils.mouseClick( 4, 4, Qt::LeftButton, Qt::KeyboardModifiers() );
+  utils.mouseClick( 7, 4, Qt::LeftButton, Qt::KeyboardModifiers() );
+  utils.mouseClick( 7.5, 3, Qt::LeftButton, Qt::KeyboardModifiers() );
+  utils.mouseClick( 7.5, 1, Qt::LeftButton, Qt::KeyboardModifiers() );
+  utils.mouseClick( 7, 0, Qt::LeftButton, Qt::KeyboardModifiers() );
+  utils.mouseClick( 4, 0, Qt::LeftButton, Qt::KeyboardModifiers() );
+  utils.mouseClick( 4, 0, Qt::RightButton );
+
+  QCOMPARE( mLayerTopo2->getFeature( 1 ).geometry().asWkt(), QStringLiteral( "Polygon ((0 5, 4 5, 4 7, 0 7, 0 5))" ) );
+  QCOMPARE( mLayerTopo->getFeature( 1 ).geometry().asWkt(), QStringLiteral( "Polygon ((4 0, 0 0, 0 4, 4 4, 7 4, 7 0, 4 0))" ) );
+  QCOMPARE( mLayerTopo->getFeature( 2 ).geometry().asWkt(), QStringLiteral( "Polygon ((7 0, 8 0, 8 4, 7 4, 7 0))" ) );
+
+  mLayerTopo->undoStack()->undo();
+
+  QCOMPARE( mLayerTopo2->getFeature( 1 ).geometry().asWkt(), QStringLiteral( "Polygon ((0 5, 4 5, 4 7, 0 7, 0 5))" ) );
+  QCOMPARE( mLayerTopo->getFeature( 1 ).geometry().asWkt(), QStringLiteral( "Polygon ((0 0, 4 0, 4 4, 0 4, 0 0))" ) );
+  QCOMPARE( mLayerTopo->getFeature( 2 ).geometry().asWkt(), QStringLiteral( "Polygon ((7 0, 8 0, 8 4, 7 4, 7 0))" ) );
+
+  mLayerTopo->removeSelection();
+  QgsProject::instance()->setTopologicalEditing( topologicalEditing );
+  QgsProject::instance()->setAvoidIntersectionsMode( mode );
+  QgsProject::instance()->setAvoidIntersectionsLayers( vlayers );
+  mCaptureTool->setAutoSnapEnabled( isAutoSnapEnabled );
+}
+
 void TestQgsMapToolReshape::reshapeWithBindingLine()
 {
   // prepare vector layer
@@ -531,11 +649,42 @@ void TestQgsMapToolReshape::testKeepDirection()
   QString wkt3 = QStringLiteral( "LineString (13 1, 12 1, 12 3, 13 3, 14 3, 14 5, 13 5, 12 5, 12 7, 13 7, 13 8, 19 11, 25 8, 25 0, 13 0, 13 1)" );
   QCOMPARE( mLayerLine->getFeature( 3 ).geometry().asWkt(), wkt3 );
 
+  // undo the three changes
+  mLayerLine->undoStack()->undo();
+  mLayerLine->undoStack()->undo();
+  mLayerLine->undoStack()->undo();
+
   // activate back snapping
   cfg.setEnabled( true );
   mCanvas->snappingUtils()->setConfig( cfg );
 }
 
+void TestQgsMapToolReshape::testWithSnapToSegment()
+{
+  TestQgsMapToolAdvancedDigitizingUtils utils( mCaptureTool );
+  mCanvas->setLayers( { mLayerPolygonZ } );
+  mCanvas->setCurrentLayer( mLayerPolygonZ );
+  mCanvas->setDestinationCrs( mLayerPolygonZ->crs() );
+
+  QgsSnappingConfig cfg = mCanvas->snappingUtils()->config();
+  cfg.setTypeFlag( static_cast<Qgis::SnappingTypes>( Qgis::SnappingType::Segment ) );
+  mCanvas->snappingUtils()->setConfig( cfg );
+
+  QCOMPARE( mLayerPolygonZ->getFeature( 1 ).geometry().asWkt(), QStringLiteral( "Polygon Z ((7 5 4, 3 2 1, 0 1 2, 7 5 4))" ) );
+
+  // snap to segment on a diagonal
+  utils.mouseClick( 5.5, 4.5, Qt::LeftButton, {}, true );
+  utils.mouseClick( 1, 5, Qt::LeftButton );
+  utils.mouseClick( 1, 2, Qt::LeftButton, {}, true );
+  utils.mouseClick( 1, 2, Qt::RightButton );
+
+  QCOMPARE( mLayerPolygonZ->getFeature( 1 ).geometry().asWkt( 1 ), QStringLiteral( "Polygon Z ((1.2 1.7 333, 1 5 333, 5.7 4.2 333, 7 5 4, 3 2 1, 0 1 2, 1.2 1.7 333))" ) );
+
+  mLayerLine->undoStack()->undo();
+
+  cfg.setTypeFlag( static_cast<Qgis::SnappingTypes>( Qgis::SnappingType::Vertex | Qgis::SnappingType::Segment ) );
+  mCanvas->snappingUtils()->setConfig( cfg );
+}
 
 QGSTEST_MAIN( TestQgsMapToolReshape )
 #include "testqgsmaptoolreshape.moc"
